==> swaggerit-0.6.1.tar.gz: swaggerit-0.6.1/swaggerit/constants.py <==
# MIT License

# Copyright (c) 2016 Diogo Dutra <dutradda@gmail.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from swaggerit.utils import build_validator, get_model_schema, get_dir_path
import os.path


HTTP_METHODS = ('delete', 'get', 'head', 'options', 'patch', 'post', 'put')


SWAGGER_TEMPLATE = get_model_schema(__file__, 'swagger_template.json')


SWAGGER_SCHEMA = get_model_schema(__file__, 'swagger_schema_extended.json')


SWAGGER_VALIDATOR = build_validator(
    {'$ref': 'swagger_schema_extended.json#/definitions/paths'},
    get_dir_path(__file__)
)

==> swaggerit-0.13.0.tar.gz: swaggerit-0.13.0/swaggerit/constants.py <==
# MIT License

# Copyright (c) 2016 Diogo Dutra <dutradda@gmail.com>

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


from swaggerit.utils import build_validator, get_swagger_json, get_dir_path
import os.path


HTTP_METHODS = ('delete', 'get', 'head', 'options', 'patch', 'post', 'put')


SWAGGER_JSON_TEMPLATE = get_swagger_json(__file__, 'swagger_template.json')


SWAGGER_SCHEMA = get_swagger_json(__file__, 'swagger_schema_extended.json')


SWAGGER_VALIDATOR = build_validator(
    {'$ref': 'swagger_schema_extended.json#/definitions/paths'},
    get_dir_path(__file__)
)
